/* 
 * dictionary.h --
 *
 *  This is the header file for the module that implements dictionaries for 
 *  Tcl. This file defines the public interface of the dictionary module.
 *
 * Copyright (c) 1999-2000 Frdric BONNET <frederic.bonnet@ciril.fr>
 *
 * See the file "license.txt" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef _DICTIONARY_H_
#define _DICTIONARY_H_

#include <tcl.h>

/*
 * if the BUILD_dictionary macro is defined, the assumption is that we are
 * building the dynamic library.
 */

#ifdef BUILD_dictionary
#  undef TCL_STORAGE_CLASS
#  define TCL_STORAGE_CLASS DLLEXPORT
#endif

/*
 *--------------------------------------------------------------
 *
 * Various stuff
 *
 *--------------------------------------------------------------
 */

#define EXPORT(a,b) a b

#ifdef WIN32
#   define WIN32_LEAN_AND_MEAN
#   include <windows.h>
#   undef WIN32_LEAN_AND_MEAN

#   ifndef STATIC_BUILD
#       if defined(__BORLANDC__)
#           undef EXPORT
#           define EXPORT(a,b) a _export b
#       endif
#   endif
#endif	/* WIN32 */


/*
 *--------------------------------------------------------------
 *
 * Structures
 *
 *--------------------------------------------------------------
 */

/*
 *--------------------------------------------------------------
 *
 * Functions
 *
 *--------------------------------------------------------------
 */

/*
 * The main entry point
 */
EXTERN EXPORT(int,Dictionary_Init)     _ANSI_ARGS_((Tcl_Interp *interp));
EXTERN EXPORT(int,Dictionary_SafeInit) _ANSI_ARGS_((Tcl_Interp *interp));


/*
 * Dictionary Tcl command
 */

int DictionaryObjCmd _ANSI_ARGS_((ClientData clientData, Tcl_Interp *interp,
				  int objc, Tcl_Obj *CONST objv[]));

/* 
 * Dictionary object interface
 */

Tcl_Obj* Dict_NewDictionaryObj _ANSI_ARGS_((int objc, 
					   Tcl_Obj *CONST objv[]));


int Dict_DictionaryObjGetSize      _ANSI_ARGS_((Tcl_Interp *interp,
					       Tcl_Obj *dictPtr,
					       int *sizePtr));
int Dict_DictionaryObjGetElement   _ANSI_ARGS_((Tcl_Interp *interp,
					       Tcl_Obj *dictPtr, 
					       char *key,
					       Tcl_Obj **objPtrPtr));
int Dict_DictionaryObjSetElement   _ANSI_ARGS_((Tcl_Interp *interp,
					       Tcl_Obj *dictPtr, 
					       char *key,
					       Tcl_Obj *valuePtr,
					       int *newPtr));
int Dict_DictionaryObjUnsetElement _ANSI_ARGS_((Tcl_Interp *interp,
					       Tcl_Obj *dictPtr, 
					       char *key));
int Dict_DictionaryObjGetElements  _ANSI_ARGS_((Tcl_Interp *interp,
					       Tcl_Obj *dictPtr,
					       Tcl_HashTable **tablePtrPtr));	/* Where to store table */

/*
 * end of dictionary.h
 * reset TCL_STORAGE_CLASS to DLLIMPORT.
 */

# undef TCL_STORAGE_CLASS
# define TCL_STORAGE_CLASS DLLIMPORT

#endif /* _DICTIONARY_H_ */
